@@ -5,9 +5,10 @@ import click
 
 from aiida.cmdline.params.options import PROFILE as VERDI_PROFILE
 from aiida.cmdline.params.types import ProfileParamType as VerdiProfileParamType
-from aiida.manage.configuration import Profile
+from aiida.manage.configuration import get_config, Profile
 
 from aiida_optimade.cli.options import AIIDA_PROFILES
+from aiida_optimade.cli.utils import AIIDA_OPTIMADE_TEST_PROFILE
 
 
 @click.group(context_settings={"help_option_names": ["-h", "--help"]})
@@ -16,19 +17,31 @@ from aiida_optimade.cli.options import AIIDA_PROFILES
 )
 @VERDI_PROFILE(
     type=VerdiProfileParamType(),
-    default="optimade_sqla",
+    default="optimade",
     show_default=True,
     help="AiiDA profile to use and serve. Configured profiles: "
     f"{', '.join([repr(name) for name in AIIDA_PROFILES])}.",
 )
+@click.option(
+    "--dev",
+    is_flag=True,
+    default=False,
+    show_default=True,
+    help=f"Run in development mode (use the {AIIDA_OPTIMADE_TEST_PROFILE!r} AiiDA "
+    "profile and `--debug` options).",
+)
 @click.pass_context
-def cli(ctx, profile: Profile):  # pragma: no cover
+def cli(ctx, profile: Profile, dev: bool):  # pragma: no cover
     """AiiDA-OPTIMADE command line interface (CLI)."""
 
     if ctx.obj is None:
         ctx.obj = {}
 
+    if dev:
+        profile = get_config(create=True).get_profile(AIIDA_OPTIMADE_TEST_PROFILE)
+
     ctx.obj["profile"] = profile
+    ctx.obj["dev"] = dev
 
     # Set config
     if (
